@@ -4,6 +4,8 @@
 """
 Show a link to the corresponding source code at the top of :rst:dir:`automodule` output.
 
+.. extensions:: sphinx_toolbox.more_autodoc.sourcelink
+
 .. versionadded:: 0.6.0
 """
 #
@@ -30,11 +32,14 @@ Show a link to the corresponding source code at the top of :rst:dir:`automodule`
 
 # stdlib
 from types import ModuleType
-from typing import Any, Dict, List
+from typing import List
 
 # 3rd party
 from sphinx.application import Sphinx
 
+# this package
+from sphinx_toolbox.utils import SphinxExtMetadata
+
 __all__ = ["sourcelinks_process_docstring", "setup"]
 
 
@@ -67,7 +72,7 @@ def sourcelinks_process_docstring(
 		lines.insert(3, '')
 
 
-def setup(app: Sphinx) -> Dict[str, Any]:
+def setup(app: Sphinx) -> SphinxExtMetadata:
 	"""
 	Setup :mod:`sphinx_toolbox.more_autodoc.sourcelink`.
 
